<?php

// WP 3.4 Theme Customizer
global $eduknows_use_customizer_type, $eduknows_use_customizer_id;

$eduknows_use_customizer_type = array('colorpicker');
$eduknows_use_customizer_id = array(
	$shortname . $shortprefix  . "site_custom_name",
	$shortname . $shortprefix  . "site_custom_description",
	$shortname . $shortprefix  . "top_faq_header",
	//$shortname . $shortprefix  . "top_faq", // textarea not supported yet
	$shortname . $shortprefix  . "headline_font",
	$shortname . $shortprefix  . "body_font",
	$shortname . $shortprefix  . "font_size",
	$shortname . $shortprefix  . "body_bg",
);

/*
 * Custom control class
 *
 * Add description on control
 * */
if ( class_exists('WP_Customize_Control') ) {
class WPMUDEV_Customize_Control extends WP_Customize_Control {

	public $description = '';

	protected function render_content() {
		switch( $this->type ) {
			default:
				return parent::render_content();
			case 'text':
				?>
				<label>
					<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
					<?php if ( isset($this->description) && !empty($this->description) ): ?>
					<span class="customize-control-description"><?php echo $this->description ?></span>
					<?php endif ?>
					<input type="text" value="<?php echo esc_attr( $this->value() ); ?>" <?php $this->link(); ?> />
				</label>
				<?php
				break;
			case 'radio':
				if ( empty( $this->choices ) )
					return;

				$name = '_customize-radio-' . $this->id;

				?>
				<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<?php if ( isset($this->description) && !empty($this->description) ): ?>
				<span class="customize-control-description"><?php echo $this->description ?></span>
				<?php endif ?>
				<?php
				foreach ( $this->choices as $value => $label ) :
					?>
					<label>
						<input type="radio" value="<?php echo esc_attr( $value ); ?>" name="<?php echo esc_attr( $name ); ?>" <?php $this->link(); checked( $this->value(), $value ); ?> />
						<?php echo esc_html( $label ); ?><br/>
					</label>
					<?php
				endforeach;
				break;
			case 'select':
				if ( empty( $this->choices ) )
					return;

				?>
				<label>
					<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
					<?php if ( isset($this->description) && !empty($this->description) ): ?>
					<span class="customize-control-description"><?php echo $this->description ?></span>
					<?php endif ?>
					<select <?php $this->link(); ?>>
						<?php
						foreach ( $this->choices as $value => $label )
							echo '<option value="' . esc_attr( $value ) . '"' . selected( $this->value(), $value, false ) . '>' . $label . '</option>';
						?>
					</select>
				</label>
				<?php
				break;
		}
	}

}
}

if ( class_exists('WP_Customize_Color_Control') ) {
class WPMUDEV_Customize_Color_Control extends WP_Customize_Color_Control {

	public $description = '';

	public function render_content() {
		?>
		<label>
			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			<?php if ( isset($this->description) && !empty($this->description) ): ?>
			<span class="customize-control-description"><?php echo $this->description ?></span>
			<?php endif ?>
			<div class="customize-control-content">
				<div class="dropdown">
					<div class="dropdown-content">
						<div class="dropdown-status"></div>
					</div>
					<div class="dropdown-arrow"></div>
				</div>
				<input class="color-picker-hex" type="text" maxlength="7" placeholder="<?php esc_attr_e('Hex Value'); ?>" />
			</div>
			<div class="farbtastic-placeholder"></div>
		</label>
		<?php
	}
}
}

function eduknows_customize_register( $wp_customize ) {
	global $options, $shortname, $shortprefix, $bp_existed, $eduknows_use_customizer_type, $eduknows_use_customizer_id;
	$sections = array(
		array(
			'section' => 'site',
			'title' => __("Site Settings", TEMPLATE_DOMAIN),
			'priority' => 30
		), array(
			'section' => 'main',
			'title' => __("Main Settings", TEMPLATE_DOMAIN),
			'priority' => 31
		), array(
			'section' => 'css',
			'title' => __("CSS Settings", TEMPLATE_DOMAIN),
			'priority' => 32
		), array(
			'section' => 'sbox',
			'title' => __("Search Box Settings", TEMPLATE_DOMAIN),
			'priority' => 33
		)
	);
	// Add sections
	foreach ( $sections as $section ) {
		$wp_customize->add_section( $shortname . $shortprefix . $section['section'], array(
			'title' => $section['title'],
			'priority' => $section['priority']
		) );
	}
	// Add settings and controls
	foreach ( $options as $o => $option ) {
		if ( ! eduknows_option_in_customize($option) )
			continue;
		$wp_customize->add_setting( $option['id'], array(
			'default' => $option['std'],
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'transport' => 'postMessage'
		) );
		$control_param = array(
			'label' => strip_tags($option['name']),
			'description' => ( isset($option['description']) && !empty($option['description']) ? $option['description'] : '' ),
			'section' => $shortname . $shortprefix . $option['inblock'],
			'settings' => $option['id'],
			'priority' => $o // make sure we have the same order as theme options :)
		);
		if ( $option['type'] == 'text' ) {
			$control_param['type'] = 'text';
			$wp_customize->add_control( new WPMUDEV_Customize_Control( $wp_customize, $option['id'].'_control', $control_param) );
		}
		else if ( $option['type'] == 'select' || $option['type'] == 'select-preview' ) {
			$control_param['type'] = 'select';
			// @TODO choices might get removed in future
			$choices = array();
			foreach ( $option['options'] as $choice )
				$choices[$choice] = $choice;
			$control_param['choices'] = $choices;
			$wp_customize->add_control( new WPMUDEV_Customize_Control( $wp_customize, $option['id'].'_control', $control_param) );
		}
		else if ( $option['type'] == 'colorpicker' ) {
			$wp_customize->add_control( new WPMUDEV_Customize_Color_Control( $wp_customize, $option['id'].'_control', $control_param ) );
		}
	}
	// Remove Wordpress default Site Title and Tagline as we have the same options
	$wp_customize->remove_setting('blogname');
	$wp_customize->remove_control('blogname');
	$wp_customize->remove_setting('blogdescription');
	$wp_customize->remove_control('blogdescription');

	// Add transport script
	if ( $wp_customize->is_preview() && ! is_admin() )
		add_action('wp_footer', 'eduknows_customize_preview', 21);
}
add_action('customize_register', 'eduknows_customize_register');

function eduknows_customize_preview() {
	global $options, $shortname, $shortprefix;
	?>
	<div id="theme-customizer-css"></div>

	<script type="text/javascript">
		var theme_customizer_css = [];
		function theme_update_css(){
			var css = '';
			for ( s in theme_customizer_css ){
				css += theme_customizer_css[s].selector + '{';
				for ( p in theme_customizer_css[s].properties ){
					var property = theme_customizer_css[s].properties[p];
					for ( v in property ){
						if ( v == 0 || v == 1 ) continue;
						css += property[0] + ':' + property[v] + property[1] + ';';
					}
				}
				css += '}';
			}
			jQuery('#theme-customizer-css').html('<style type="text/css">'+css+'</style>');
		}
		function theme_change_style( selector_list, property, values, priority ){
			if ( !priority ) priority = '';
			var prop = [property, priority];
			if ( typeof values == 'string' ) prop.push(values);
			else {
				for ( v in values ) prop.push(values[v]);
			}
			var add_selector = true, add_property = true;
			for ( s in theme_customizer_css ){
				if ( theme_customizer_css[s].selector == selector_list ){
					add_selector = false;
					for ( p in theme_customizer_css[s].properties ){
						if ( theme_customizer_css[s].properties[p][0] == property ){
							theme_customizer_css[s].properties[p] = prop;
							add_property = false;
							break;
						}
					}
					if ( add_property ) theme_customizer_css[s].properties.push(prop)
				}
			}
			if ( add_selector ){
				theme_customizer_css.push({
					selector: selector_list,
					properties: [prop]
				});
			}
			theme_update_css();
		}
		function theme_change_font_family( selector, value, priority ){
			// load font from Google Fonts API
			var fonts = value.split(',');
			var font = fonts[0];
			var supported_fonts = ["Cantarell", "Cardo", "Crimson Text", "Droid Sans", "Droid Serif", "IM Fell DW Pica",
				"Josefin Sans Std Light", "Lobster", "Molengo", "Neuton", "Nobile", "OFL Sorts Mill Goudy TT",
				"Reenie Beanie", "Tangerine", "Old Standard TT", "Volkorn", "Yanone Kaffessatz", "Just Another Hand",
				"Terminal Dosis Light", "Ubuntu"];
			var load_external = false;
			for ( i in supported_fonts ){
				if ( font == supported_fonts[i] ){
					load_external = true;
					break;
				}
			}
			if ( load_external ){
				if ( font == 'Ubuntu' ) font += ":light,regular,bold";
				font = font.replace(' ', '+');
				jQuery('body').append("<link href='http://fonts.googleapis.com/css?family="+font+"' rel='stylesheet' type='text/css'/>");
			}
			theme_change_style(selector, 'font-family', value, priority);
		}

		window.onload = function(){
		<?php foreach ( $options as $option ): ?>
			<?php if ( ! eduknows_option_in_customize($option) ) continue; ?>
			wp.customize( '<?php echo $option['id'] ?>', function(value) {
				value.bind(function(to){
					<?php if ( $option['type'] != 'text' ): ?>
					if ( !to ) return;
					<?php endif ?>
					<?php
					// Use printf for better readibility, place selector in argument
					switch ( str_replace($shortname . $shortprefix, '', $option['id']) ){
						case 'body_font':
							printf("theme_change_font_family('%s', to, '!important');", "body");
							break;
						case 'headline_font':
							printf("theme_change_font_family('%s', to, '!important');", "h1, h2, h3, h4, h5, h6");
							break;
						case 'body_bg':
							printf("if ( to == 'Red' ) var bg = 'bg-red.gif';");
							printf("else if ( to == 'Yellow' ) var bg = 'bg-yellow.gif';");
							printf("else if ( to == 'Grey' ) var bg = 'bg-grey.gif';");
							printf("else if ( to == 'White Shade' ) var bg = 'bg-white-shade.gif';");
							printf("else if ( to == 'Light Brown' ) var bg = 'bg-brown.gif';");
							printf("else if ( to == 'Light Green' ) var bg = 'bg-light-green.gif';");
							printf("else if ( to == 'Dark Green' ) var bg = 'bg-dark-green.gif';");
							printf("else if ( to == 'White' ) var bg = 'spacer.gif';");
							printf("else var bg = 'bg.gif';");
							printf("theme_change_style('%s', 'background-image', 'url(%s'+bg+')', '!important'); ", "body", get_template_directory_uri().'/images/');
							break;
						case 'font_size':
							printf("if ( to == 'small' ) var size = '0.5em';");
							printf("else if ( to == 'bigger' ) var size = '0.85em';");
							printf("else if ( to == 'largest' ) var size = '0.9125em';");
							printf("else var size = '0.6875em';");
							printf("theme_change_style('%s', 'font-size', size); ", "#wrap");
							break;
						case 'content_link_colour':
							printf("theme_change_style('%s', 'color', to, '!important'); ", "#content a");
							printf("theme_change_style('%s', 'background-color', to, '!important'); ", "#wrap #fulltag a, #wrap #fulltag a:hover");
							printf("theme_change_style('%s', 'background-color', to, '!important'); ", "#nav li a:hover, #nav li.home a, #nav li.current_page_item a, #nav li li a, #nav li li a:hover, #nav li:hover a, #post-navigator a");
							printf("theme_change_style('%s', 'background-color', to, '!important'); ", "#entry .nolist li a:hover");
							printf("theme_change_style('%s', 'background-color', to, '!important'); ", "#container ol.commentlist li div.reply a, #container ol.commentlist li div.reply a:hover");
							break;
						case 'searchbox_colour':
							printf("theme_change_style('%s', 'background-color', to, '!important'); ", "#searchbar #mysearch");
							break;
						case 'searchbox_border_colour':
							printf("theme_change_style('%s', 'border-color', to, '!important'); ", "#searchbar #mysearch");
							break;
						case 'site_custom_name':
							printf("jQuery('%s').html(to); ", "#site-title h1");
							break;
						case 'site_custom_description':
							printf("jQuery('%s').html(to); ", "#site-title p");
							break;
						case 'top_faq_header':
							printf("jQuery('%s').html(to); ", "#intro h2");
							break;

					}
					?>
				});
			} );
		<?php endforeach ?>
		};
	</script>
	<?php
}

// Add additional styling to better fit on Customizer options
function eduknows_customize_controls_footer() {
	?>
	<style type="text/css">
		.customize-control-title { line-height: 18px; padding: 2px 0; }
		.customize-control-description { font-size: 11px; color: #666; margin: 0 0 3px; display: block; }
	</style>
	<?php
}
add_action('customize_controls_print_footer_scripts', 'eduknows_customize_controls_footer');

function eduknows_option_in_customize( $option ) {
	global $eduknows_use_customizer_type, $eduknows_use_customizer_id;
	if ( in_array($option['type'], $eduknows_use_customizer_type) || in_array($option['id'], $eduknows_use_customizer_id) )
		return true;
	return false;
}

?>